@@ -13,7 +13,7 @@ namespace fcitx {
 
 class RimeState : public InputContextProperty {
 public:
-    RimeState(RimeEngine *engine);
+    RimeState(RimeEngine *engine, InputContext &ic);
 
     virtual ~RimeState();
 
@@ -24,10 +24,18 @@ public:
     void updateUI(InputContext *ic, bool keyRelease);
     void release();
     void commitPreedit(InputContext *ic);
+    std::string subMode();
+    std::string subModeLabel();
+    void setLatinMode(bool latin);
+    void selectSchema(const std::string &schemaId);
 
 private:
+    void createSession();
+
+    std::string lastMode_;
     RimeEngine *engine_;
     RimeSessionId session_ = 0;
+    InputContext &ic_;
 };
 } // namespace fcitx
 
